# flake8: noqa

"""
    Open:Risk API

    Service to calculate parametric linear risk statistics and generate risk model asset identifier mappings.  # noqa: E501

    The version of the OpenAPI document: 1.26.0
    Contact: api@factset.com
    Generated by: https://openapi-generator.tech
"""


__version__ = "4.0.2"

# import ApiClient
from fds.sdk.OpenRisk.api_client import ApiClient

# import Configuration
from fds.sdk.OpenRisk.configuration import Configuration

# import exceptions
from fds.sdk.OpenRisk.exceptions import OpenApiException
from fds.sdk.OpenRisk.exceptions import ApiAttributeError
from fds.sdk.OpenRisk.exceptions import ApiTypeError
from fds.sdk.OpenRisk.exceptions import ApiValueError
from fds.sdk.OpenRisk.exceptions import ApiKeyError
from fds.sdk.OpenRisk.exceptions import ApiException
